package main

import (
	"flag"
	"fmt"
	"log"
	"os"
	"os/signal"
	"syscall"

	"github.com/azoic/wormhole-server/internal/server"
)

var (
	version   = "v1.0.0"
	buildTime = "unknown"
)

func main() {
	configPath := flag.String("config", "configs/server.yaml", "Configuration file path")
	showVersion := flag.Bool("version", false, "Show version information")
	flag.Parse()

	if *showVersion {
		fmt.Printf("Wormhole SOCKS5 Server %s\n", version)
		fmt.Printf("Build time: %s\n", buildTime)
		os.Exit(0)
	}

	fmt.Printf("🚀 Starting Wormhole SOCKS5 Server %s\n", version)
	fmt.Printf("📄 Config: %s\n", *configPath)

	// 创建服务器实例
	srv := server.NewServer()

	// 设置信号处理
	sigChan := make(chan os.Signal, 1)
	signal.Notify(sigChan, syscall.SIGINT, syscall.SIGTERM)

	// 启动服务器
	go func() {
		if err := srv.Start(*configPath); err != nil {
			log.Fatalf("Server failed to start: %v", err)
		}
	}()

	// 等待信号
	sig := <-sigChan
	fmt.Printf("\n🛑 Received signal: %v\n", sig)
	fmt.Println("🔄 Shutting down gracefully...")

	// 优雅关闭
	if err := srv.Stop(); err != nil {
		log.Printf("Error during shutdown: %v", err)
	}

	fmt.Println("✅ Server stopped")
}
